import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import '../css/global.css';
import BlackButton from './components/customButton';
import Animation from './components/animation.jsx';
import PlayVideo from './components/playVideo.jsx';
import LoadingScene from './components/loadingScene.jsx';
import IntroductionData from './components/introductionData.jsx';
import SelectionCharacter from './components/selectionCharacter.jsx';
import Character from './class/character.jsx';

function IntroductionPage() {
    const navigate = useNavigate();
    const [loading, setLoading] = useState(true);
    const [positionState, setPositionState] = useState("middle");
    const [isClickedIntroduction, setIsClickedIntroduction] = useState(false);
    const [numChar, setNumChar] = useState(1);
    const character = new Character();

    const handleLeftClicked = () => {
        setNumChar(prev => (prev - 1 < 1 ? 3 : prev - 1));
    };

    const handleRightClicked = () => {
        setNumChar(prev => (prev + 1 > 3 ? 1 : prev + 1));
    };

    const handleClickIntroduction = () => {
        setIsClickedIntroduction(true);
    };

    const handleVideoReady = () => {
        setLoading(false);
    };

    const handleClickedButton = () => {
        console.log(character.name(numChar))
        if(character.name(numChar)=='Porsche') navigate(`/vs/Porsche/0`);
        if(character.name(numChar)=='Pie') navigate(`/vs/Pie/0`);
        if(character.name(numChar)=='Patt') navigate(`/vs/Pat/0`);
    }

    return (
        <div style={{ width: "100vw", height: "100vh" }}>
            {loading ? (
                <LoadingScene />
            ) : (
                !isClickedIntroduction ? (
                    <IntroductionData onClickedIntroduction={handleClickIntroduction} />
                ) : (
                    <SelectionCharacter
                        onClickedLeft={handleLeftClicked}
                        onClickedRight={handleRightClicked}
                        nameChar={character.name(numChar)}
                        onClickedButton={handleClickedButton}
                    />
                )
            )}
            <PlayVideo
                src='hallway_FFF.mp4'
                side={character.position(numChar)}
                onVideoReady={handleVideoReady}
            />
        </div>
    );
}

export default IntroductionPage;
